@@ -1,4 +1,4 @@
-from rest_framework_simplejwt.views import TokenObtainPairView
+from rest_framework_simplejwt.views import TokenObtainPairView, TokenRefreshView as TamarinRefreshView
 from rest_framework_simplejwt.serializers import TokenObtainPairSerializer
 
 
